### This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

import sos.plugintools
import os

scriptPath = ""

class veritas(sos.plugintools.PluginBase):
    """veritas related information
    """
    # Information about VRTSexplorer obtained from
    # http://seer.entsupport.symantec.com/docs/243150.htm
    # Use the path of the latest version by default but test
    # possible alternate locations for the script and use if
    # found.
    optionList = [("script", "Define VRTSexplorer script path", "", "/opt/VRTSexplorer/VRTSexplorer")]

    def checkenabled(self):
        enabled = False
        if os.path.isfile(self.isOptionEnabled("script")): 
            enabled = True
        elif os.path.isfile("/opt/VRTSspt/VRTSexplorer/VRTSexplorer"):
            enabled = True
        elif os.path.isfile("/opt/VRTSspt/VRTSexplorer"):
            enabled = True
        return enabled
    
    def setup(self):
        """ interface with vrtsexplorer to capture veritas related data """
        if os.path.isfile(self.isOptionEnabled("script")): 
            scriptPath = self.isOptionEnabled("script")
        elif os.path.isfile("/opt/VRTSspt/VRTSexplorer/VRTSexplorer"):
            scriptPath = "/opt/VRTSspt/VRTSexplorer/VRTSexplorer"
        elif os.path.isfile("/opt/VRTSspt/VRTSexplorer"):
            scriptPath = "/opt/VRTSspt/VRTSexplorer"
        # no valid script to use
        else:
            return
        # we need to connect stdin to a non-TTY to prevent the script trying to run interactively
        stat, out, runtime = self.callExtProgWithOutput(scriptPath + " < /dev/null")
        tarfile = []
        try:
            for line in out.split('\n'):
                line = line.strip().split()
                if len(line) < 4:
                    continue
                if line[2] == 'ftp' and line[3].endswith(".tar.gz"):
                    tarfile = line[3]
            if tarfile:
                self.addCopySpec(tarfile)
        except AttributeError, e:
            self.addAlert(e)
            return
        return

